#!/bin/sh

# This script is for upgrading SetuATA file system from zip file.
# $1 will be 1/2/3/ALL for Driver/Web/Appl/All respectively.
# $2 Version
# $3 Revision
# $4 TempRevision
# $5 SystemName

FIRMWAR_UPGRADE_RAM_DIR=/ramdisk/auto_firmware/new_firmware
FIRMWAR_UPGRADE_FLASH_DIR=/matrix/upgrade

rm -rf $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
echo "Creating directory /ramdisk/auto_firmware/new_firmware" >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt

mkdir -p $FIRMWAR_UPGRADE_RAM_DIR

if [ $# != 5 ]
then
	echo "Invalid Argurment" >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
	exit
fi

arg2=$2
arg3=$3
arg4=$4
systemName=$5

if [ "$1" = "ALL" ]
then
	ls -l /usr/FirmwareUpgradeInfo
	if [ ! "$?" = "1" ]
	then
		rm -rf $FIRMWAR_UPGRADE_FLASH_DIR/*
		exit
	fi

  arg2=`awk 'NR==1' /usr/FirmwareUpgradeInfo`
  arg3=`awk 'NR==2' /usr/FirmwareUpgradeInfo`
  arg4=`awk 'NR==3' /usr/FirmwareUpgradeInfo`
	
fi

echo "Run Firmware upgrade scrip with cmd" $1 $arg2 $arg3 $arg4 $arg5 >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt


if [ "$1" = "1" ] || [ "$1" = "ALL" ]
then
	echo "driver"
	# stores firmware file in flash for backup
	if [ -f $FIRMWAR_UPGRADE_RAM_DIR/*_DRIVER.zip ]
	then
		mv $FIRMWAR_UPGRADE_RAM_DIR/*_DRIVER.zip $FIRMWAR_UPGRADE_FLASH_DIR/
		echo "$arg2" > /usr/FirmwareUpgradeInfo
		echo "$arg3" >> /usr/FirmwareUpgradeInfo
		echo "$arg4" >> /usr/FirmwareUpgradeInfo
		echo "DRIVER" >> /usr/FirmwareUpgradeInfo
	fi
	if [ -f $FIRMWAR_UPGRADE_FLASH_DIR/*_DRIVER.zip ]
	then
		if [ "$arg4" != "0" ]
		then
		  echo "Script going to upgrade driver" $arg2 $arg3 $arg4 $systemName >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
		else
		  echo "Script going to upgrade driver" $arg2 $arg3 $systemName >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
		fi
		
		# copy from Flash to RAM.
		cp $FIRMWAR_UPGRADE_FLASH_DIR/*_DRIVER.zip $FIRMWAR_UPGRADE_RAM_DIR/

		cd $FIRMWAR_UPGRADE_RAM_DIR/

 		unzip -o -q *_DRIVER.zip
 		if [ -f driver.zip ]
 		then
 			echo "DRIVER_UNZIP_FAILED"  > $FIRMWAR_UPGRADE_RAM_DIR/FirmwareUpgradeResult
 			echo "DRIVER_UNZIP_FAILED ZIP file without passwd"  >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
 			rm -rf $FIRMWAR_UPGRADE_RAM_DIR/*
			rm -rf $FIRMWAR_UPGRADE_FLASH_DIR/*_DRIVER.zip
			rm -rf /usr/FirmwareUpgradeInfo
 			exit
 		fi

		unzip -P 123456789 -o -q *_DRIVER.zip
		if [ ! -f driver.zip ]
		then
			echo "DRIVER_UNZIP_FAILED"  > $FIRMWAR_UPGRADE_RAM_DIR/FirmwareUpgradeResult
			echo "DRIVER_UNZIP_FAILED"  >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
			rm -rf $FIRMWAR_UPGRADE_RAM_DIR/*
			rm -rf $FIRMWAR_UPGRADE_FLASH_DIR/*_DRIVER.zip
			rm -rf /usr/FirmwareUpgradeInfo
			exit
		else
			# If unzip successfull then check for MD5.

			MD5RESULT=''
			md5sum -c CHECKSUM.txt > CHECKSUM_RESULT.txt
			MD5RESULT=`cat CHECKSUM_RESULT.txt | awk '{print $2}'`
			if [ ! "$MD5RESULT" = "OK" ]
			then
				echo "DRIVER_MD5_NOT_VALID"  > $FIRMWAR_UPGRADE_RAM_DIR/FirmwareUpgradeResult
				echo "DRIVER_MD5_NOT_VALID"  >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
				rm -rf $FIRMWAR_UPGRADE_RAM_DIR/*
				rm -rf $FIRMWAR_UPGRADE_FLASH_DIR/*_DRIVER.zip
				rm -rf /usr/FirmwareUpgradeInfo
				exit
			else
				# md5sum success so delete orig zip file.

				rm -rf *_DRIVER.zip
				echo "Extracting driver.zip" >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
				unzip -P 123456789 -o -q driver.zip

				rm -rf $FIRMWAR_UPGRADE_RAM_DIR/driver.zip
				rm -rf $FIRMWAR_UPGRADE_RAM_DIR/CHECKSUM*
				rm -rf $FIRMWAR_UPGRADE_FLASH_DIR/*_DRIVER.zip

				rm -f /matrix/driver/*.ko
				cp -rf driver/*.ko /matrix/driver/

				if [ -f upgrade.sh ]
				then
					chmod 777 upgrade.sh
				    echo "Going to run upgrade.sh From driver" >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt 
				    ./upgrade.sh
				fi
				
				# Store the last upgrade status for power on purpose.
				echo "$arg2" > /usr/FirmwareUpgradeInfo
				echo "$arg3" >> /usr/FirmwareUpgradeInfo
				echo "$arg4" >> /usr/FirmwareUpgradeInfo
				echo "DRIVER" >> /usr/FirmwareUpgradeInfo
		
				rm -rf $FIRMWAR_UPGRADE_RAM_DIR/driver

				echo "Successfully Copy all drivers file" >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
				echo "DRIVER_UPDATED"  > $FIRMWAR_UPGRADE_RAM_DIR/FirmwareUpgradeResult
				echo "DRIVER_UPDATED" >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
			fi
		fi
	fi
fi



if [ "$1" = "2" ] || [ "$1" = "ALL" ]
then
  echo "web"
	# stores firmware file in flash for backup
	if [ -f $FIRMWAR_UPGRADE_RAM_DIR/*_WEB.zip ]
	then
		mv $FIRMWAR_UPGRADE_RAM_DIR/*_WEB.zip $FIRMWAR_UPGRADE_FLASH_DIR/
		echo "$arg2" > /usr/FirmwareUpgradeInfo
		echo "$arg3" >> /usr/FirmwareUpgradeInfo
		echo "$arg4" >> /usr/FirmwareUpgradeInfo
		echo "WEB" >> /usr/FirmwareUpgradeInfo
	fi

	if [ -f $FIRMWAR_UPGRADE_FLASH_DIR/*_WEB.zip ]
	then
		if [ "$arg4" != "0" ]
		then
		  echo "Script going to upgrade web" $arg2 $arg3 $arg4 $systemName >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
		else
		  echo "Script going to upgrade web" $arg2 $arg3 $systemName >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
		fi
		# copy from Flash to RAM.
		cp $FIRMWAR_UPGRADE_FLASH_DIR/*_WEB.zip $FIRMWAR_UPGRADE_RAM_DIR/

		cd $FIRMWAR_UPGRADE_RAM_DIR

		unzip -o -q *_WEB.zip
 		if [ -f webresource.zip ]
 		then
 			echo "WEB_UNZIP_FAILED"  > $FIRMWAR_UPGRADE_RAM_DIR/FirmwareUpgradeResult
 			echo "WEB_UNZIP_FAILED ZIP file without passwd"  >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
 			rm -rf $FIRMWAR_UPGRADE_RAM_DIR/*
			rm -rf $FIRMWAR_UPGRADE_FLASH_DIR/*_WEB.zip
			rm -rf /usr/FirmwareUpgradeInfo
 			exit
 		fi		

		unzip -P 123456789 -o -q *_WEB.zip
		if [ ! -f webresource.zip ]
		then
			echo "WEB_UNZIP_FAILED"  > $FIRMWAR_UPGRADE_RAM_DIR/FirmwareUpgradeResult
			echo "WEB_UNZIP_FAILED"  >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
			rm -rf $FIRMWAR_UPGRADE_RAM_DIR/*
			rm -rf $FIRMWAR_UPGRADE_FLASH_DIR/*_WEB.zip
			rm -rf /usr/FirmwareUpgradeInfo
 			exit
		else
			# If unzip successfull then check for MD5.
			
			MD5RESULT=''
			md5sum -c CHECKSUM.txt > CHECKSUM_RESULT.txt
			MD5RESULT=`cat CHECKSUM_RESULT.txt | awk '{print $2}'`
			echo $MD5RESULT >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
			if [ ! "$MD5RESULT" = "OK" ]
			then
				echo "WEB_MD5_NOT_VALID"  > $FIRMWAR_UPGRADE_RAM_DIR/FirmwareUpgradeResult
				echo "WEB_MD5_NOT_VALID"  >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
				rm -rf $FIRMWAR_UPGRADE_RAM_DIR/*
				rm -rf $FIRMWAR_UPGRADE_FLASH_DIR/*_WEB.zip
				rm -rf /usr/FirmwareUpgradeInfo
 				exit
			else
				rm -rf $FIRMWAR_UPGRADE_RAM_DIR/*_WEB.zip
				rm -rf $FIRMWAR_UPGRADE_RAM_DIR/CHECHKSUM*
				rm -rf $FIRMWAR_UPGRADE_FLASH_DIR/*_WEB.zip
				echo "copying webresource.zip" >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
				#remove from flash
				rm -rf /matrix/web/*
				#copy to flash
				cp -rf $FIRMWAR_UPGRADE_RAM_DIR/webresource.zip /matrix/web/

				if [ -f upgrade.sh ]
				then
					chmod 777 upgrade.sh
				    echo "Going to run upgrade.sh From web" >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt 
				    ./upgrade.sh
				fi

				# Store the last upgrade status for power on purpose.
				echo "$arg2" > /usr/FirmwareUpgradeInfo
				echo "$arg3" >> /usr/FirmwareUpgradeInfo
				echo "$arg4" >> /usr/FirmwareUpgradeInfo
				echo "WEB" >> /usr/FirmwareUpgradeInfo

				rm -rf $FIRMWAR_UPGRADE_RAM_DIR/webresource.zip

				echo "Successfully Copy all web file" >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
				echo "WEB_UPDATED"  > $FIRMWAR_UPGRADE_RAM_DIR/FirmwareUpgradeResult
				echo "WEB_UPDATED"  >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
			fi
		fi
	fi
fi

if [ "$1" = "3" ] || [ "$1" = "ALL" ]
then
  echo "appl"
	# stores firmware file in flash for backup
	if [ -f $FIRMWAR_UPGRADE_RAM_DIR/*_APPL.zip ]
	then
		mv $FIRMWAR_UPGRADE_RAM_DIR/*_APPL.zip $FIRMWAR_UPGRADE_FLASH_DIR/
		echo "$arg2" > /usr/FirmwareUpgradeInfo
		echo "$arg3" >> /usr/FirmwareUpgradeInfo
		echo "$arg4" >> /usr/FirmwareUpgradeInfo
		echo "APPL" >> /usr/FirmwareUpgradeInfo
	fi

	if [ -f $FIRMWAR_UPGRADE_FLASH_DIR/*_APPL.zip ]
	then
		if [ "$arg4" != "0" ]
		then
		  echo "Script going to upgrade application" $arg2 $arg3 $arg4 $systemName >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
		else
		  echo "Script going to upgrade application" $arg2 $arg3 $systemName >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
		fi
		# copy from Flash to RAM.
		cp $FIRMWAR_UPGRADE_FLASH_DIR/*_APPL.zip $FIRMWAR_UPGRADE_RAM_DIR/
		cd $FIRMWAR_UPGRADE_RAM_DIR

		unzip -o -q *_APPL.zip
 		if [ -f appl.zip ]
 		then
 			echo "APP_UNZIP_FAILED"  > $FIRMWAR_UPGRADE_RAM_DIR/FirmwareUpgradeResult
 			echo "APP_UNZIP_FAILED ZIP file without passwd"  >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
 			rm -rf $FIRMWAR_UPGRADE_RAM_DIR/*
			rm -rf $FIRMWAR_UPGRADE_FLASH_DIR/*_APPL.zip
			rm -rf /usr/FirmwareUpgradeInfo
 			exit
 		fi


		unzip -P 123456789 -o -q *_APPL.zip
		if [ ! -f appl.zip ]
		then
			echo "APP_UNZIP_FAILED"  > $FIRMWAR_UPGRADE_RAM_DIR/FirmwareUpgradeResult
			echo "APP_UNZIP_FAILED"  >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
			rm -rf $FIRMWAR_UPGRADE_RAM_DIR/*
			rm -rf $FIRMWAR_UPGRADE_FLASH_DIR/*_APPL.zip
			rm -rf /usr/FirmwareUpgradeInfo
 			exit
		else
			# If unzip successfull then check for MD5.

			MD5RESULT=''
			md5sum -c CHECKSUM.txt > CHECKSUM_RESULT.txt
			MD5RESULT=`cat CHECKSUM_RESULT.txt | awk '{print $2}'`
			if [ ! "$MD5RESULT" = "OK" ]
			then
				echo "APP_MD5_NOT_VALID"  > $FIRMWAR_UPGRADE_RAM_DIR/FirmwareUpgradeResult
				echo "APP_MD5_NOT_VALID"  >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
				rm -rf $FIRMWAR_UPGRADE_RAM_DIR/*
				rm -rf $FIRMWAR_UPGRADE_FLASH_DIR/*_APPL.zip
				rm -rf /usr/FirmwareUpgradeInfo
 			exit
			else
				# md5sum success so delete orig zip file.

				rm -rf $FIRMWAR_UPGRADE_RAM_DIR/*_APPL.zip

				echo "Extracting appl.zip" >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt

				unzip -P 123456789 -o -q appl.zip
				STATUS=`echo $?`
				if [ ! $STATUS = "0" ]
				then
					echo "APP_UNZIP_FAILED"  > $FIRMWAR_UPGRADE_RAM_DIR/FirmwareUpgradeResult
					echo "APP_UNZIP_FAILED appl.zip failed"  >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
					rm -rf $FIRMWAR_UPGRADE_RAM_DIR/*
					rm -rf $FIRMWAR_UPGRADE_FLASH_DIR/*_APPL.zip
					rm -rf /usr/FirmwareUpgradeInfo
				  	exit
				fi

				rm -rf $FIRMWAR_UPGRADE_RAM_DIR/appl.zip
				rm -rf $FIRMWAR_UPGRADE_RAM_DIR/CHECKSUM*
				

				# kill the application as per product
				# application name must be same other wise command get failed take care of it
				# command get failed it can create problem. Firmware upgarde may be get failed and board not work
				kill -9 `pidof SetuATA.sh`
				sleep 5

				APP_STATUS="0"
				echo $systemName >> /matrix/driver/systemName
				if [ "$systemName" = "SetuATA1S" ]
				then
					APP_STATUS="1"
	  				kill -s SIGKILL `pidof setu_ata1s`
				else if [ "$systemName" = "SetuATA211" ]
				then
					APP_STATUS="1"
	  				kill -s SIGKILL `pidof setu_ata211`
				else if [ "$systemName" = "SetuATA2S" ]
				then 												
					APP_STATUS="1"
	  				kill -s SIGKILL `pidof setu_ata2s`
						echo "Kill ATA 2S"
				else if [ "$systemName" = "SetuATA211G" ]
				then
					APP_STATUS="1"
	  				kill -s SIGKILL `pidof setu_ata211g`
				fi
				fi
				fi
				fi
				sleep 5

				if [ "APP_STATUS" = "0" ]
				then
					echo "APP_KILL FAILED"  > $FIRMWAR_UPGRADE_RAM_DIR/FirmwareUpgradeResult
					echo "APP_KILL FAILED failed"  >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
					rm -rf $FIRMWAR_UPGRADE_RAM_DIR/*
					rm -rf $FIRMWAR_UPGRADE_FLASH_DIR/*_APPL.zip
					rm -rf /usr/FirmwareUpgradeInfo
				  	exit
				fi
				rm -rf /matrix/dhcp/*.script
				rm -rf /matrix/ppp/*.*
				rm -rf /matrix/system/scripts/*.sh
				rm -rf /matrix/system/setu_ata*
				rm -rf $FIRMWAR_UPGRADE_FLASH_DIR/*_APPL.zip
				sleep 5
				echo "Start copying application files to flash."
				cp -rf $FIRMWAR_UPGRADE_RAM_DIR/dhcp/*.script /matrix/dhcp/
				cp -rf $FIRMWAR_UPGRADE_RAM_DIR/ppp/* /matrix/ppp/
				cp -rf $FIRMWAR_UPGRADE_RAM_DIR/system/scripts/*.sh /matrix/system/scripts/
				cp -rf $FIRMWAR_UPGRADE_RAM_DIR/system/setu_ata* /matrix/system/
				sleep 10 

				echo "Finish copying application files to flash."
				if [ -f upgrade.sh ]
				then
					chmod 777 upgrade.sh
				     echo "Going to run upgrade.sh From Appl" >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt 
				    ./upgrade.sh
				fi

				# application file is successfully upgraded so update info file.
				
				echo "$arg2" > /usr/FirmwareUpgradeInfo
				echo "$arg3" >> /usr/FirmwareUpgradeInfo
				echo "$arg4" >> /usr/FirmwareUpgradeInfo
				echo "APPL" >> /usr/FirmwareUpgradeInfo

				echo "APP_UPDATED"  > $FIRMWAR_UPGRADE_RAM_DIR/FirmwareUpgradeResult

				echo "Successfully Copy all appl file" >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt
				echo "APP_UPDATED"  >> $FIRMWAR_UPGRADE_FLASH_DIR/firmwarelog.txt		  
				reboot
			fi
		fi
	fi
fi
